CON

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000

  mouse_data_pin = 24
  mouse_clock_pin = 25

  cols = 40
  rows = 25
  chrs = cols * rows 'number of screen character locations

  keyboard  = 26 '' I/O for keyboard connection
  video     = 12

  '' Basic Color Settings

  BLACK             = $02 
  GREY              = $03
  LWHITE            = $06
  BWHITE            = $07
  LMAGENTA          = $A3 
  WHITE             = $AF
  RED               = $A2
  LRED              = $1A
  LPURPLE           = $1B
  PURPLE            = $03 
  LGREEN            = $1C
  SKYBLUE           = $1D
  YELLOW            = $1E
  BYELLOW           = $A6
  LGREY             = $1F
  DGREY             = $08
  GREEN             = $A4
  ORANGE            = $06
  BLUE              = $A1 
  CYAN              = $1C
  MAGENTA           = $FC
  LYELLOW           = $1E

  CR                            = $0D
  LF                            = $0A
  TAB                           = $09
  BKS                           = $08    
OBJ

  text    : "aigeneric_driver"
  mouse   : "mouse"
  key     : "comboKeyboard"

VAR

  long mousex 
  long mousey

  long brushSize
  long color

PUB start | i, j, keyval, lx, ly, replacer

  'Start mouse
  mouse.start(mouse_data_pin, mouse_clock_pin)
  mouse.bound_limits(0, 0, 0, cols - 1, rows - 1, 0)
  mouse.bound_scales(10, -10, 0)

  'Start keyboard
  key.start(keyboard)

  'Start video
  text.start(video)
  
  'Intro
  text.color(PURPLE)  
  text.str(string("PropPaint v0.7", CR))
  text.str(string("Created by Owen Trueblood", CR, CR))

  text.color(YELLOW)  
  text.str(string("Instructions:", CR))
  text.str(string("*Use the mouse to move the cursor around", CR))
  text.str(string("*Use the left mouse button to paint.", CR))
  text.str(string("*Use the right mouse button to erase.", CR))
  text.str(string("*Use the keyboard keys 1-3 to set the   brush size.", CR))
  text.str(string("*Hit enter to clear the screen.", CR, CR))

  text.str(string("Press any key to continue.", CR))    

  repeat 1000000
  
  'Wait until the user does something
  repeat while keyval == 0 and mouse.button(0)==false and mouse.button(1)==false
    'get keypresses
    keyval := key.key

  text.cls

  brushSize := 0
  color := WHITE

  lx := mouse.bound_x
  ly := mouse.bound_y
  replacer := 32
  
  'Main loop
  repeat
    mousex := mouse.bound_x
    mousey := mouse.bound_y
    
    'get keypresses
    keyval := key.key
        
    'Reboot if esc is pressed
    if keyval == 203
      reboot

    if mouse.button(0) or mouse.button(1)
      'left mouse button pressed
      if mouse.button(0)
        paint(mousex, mousey, brushSize, color)
        
        lx := mousex
        ly := mousey        
       
      'right mouse button pressed
      if mouse.button(1)
        erase(mousex, mousey, brushSize, WHITE)
    else
      if not lx==mousex or not ly==mousey
        text.poke(lx, ly, WHITE, replacer)
        replacer := text.get(mousex, mousey)
        text.poke(mousex, mousey, WHITE, $0F)

      lx := mousex
      ly := mousey

    'use keyboard to set brush size
    if keyval-49 > -1 and keyval-49 < 3
      brushSize := keyval-49

    'enter pressed
    if keyval == 13
      text.cls

PRI paint(x, y, size, cl)

  if size==0
    text.poke(x, y, cl, $0F)
  if size==1
    text.poke(x, y, cl, $0F)
    text.poke(x, y-1, cl, $0F)
    text.poke(x, y+1, cl, $0F)
    text.poke(x-1, y, cl, $0F)
    text.poke(x+1, y, cl, $0F)
  if size==2
    text.poke(x, y, cl, $0F)
    text.poke(x, y-1, cl, $0F)
    text.poke(x, y+1, cl, $0F)
    text.poke(x-1, y, cl, $0F)
    text.poke(x+1, y, cl, $0F)
    text.poke(x-1, y-1, cl, $0F)
    text.poke(x-1, y+1, cl, $0F)
    text.poke(x+1, y-1, cl, $0F)
    text.poke(x+1, y+1, cl, $0F)
    
PRI erase(x, y, size, cl)

  if size==0
    text.poke(x, y, cl, 32)
  if size==1
    text.poke(x, y, cl, 32)
    text.poke(x, y-1, cl, 32)
    text.poke(x, y+1, cl, 32)
    text.poke(x-1, y, cl, 32)
    text.poke(x+1, y, cl, 32)
  if size==2
    text.poke(x, y, cl, 32)
    text.poke(x, y-1, cl, 32)
    text.poke(x, y+1, cl, 32)
    text.poke(x-1, y, cl, 32)
    text.poke(x+1, y, cl, 32)
    text.poke(x-1, y-1, cl, 32)
    text.poke(x-1, y+1, cl, 32)
    text.poke(x+1, y-1, cl, 32)
    text.poke(x+1, y+1, cl, 32)
  